
Changelog
=========

0.1.0 (2020-06-09)
------------------

* First release on PyPI.


0.1.1 (2020-08-06)
------------------

* Minor patch to documentation and change log.

0.2.0 (2020-09-03)
------------------

* Update to pynwb 1.3.2
* handles up to LabView 2.3.1
* red and green channels now on same imaging plane
* manifold replaced by origin coordinates and grid spacing
